@@ -22,6 +22,7 @@ import os
 import re
 
 import os_net_config
+from os_net_config import common
 from os_net_config import objects
 from os_net_config import utils
 
@@ -247,7 +248,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         :returns: boolean value for whether a restart is required
         """
 
-        file_data = utils.get_file_data(filename)
+        file_data = common.get_file_data(filename)
         logger.debug("Original ifcfg file:\n%s" % file_data)
         logger.debug("New ifcfg file:\n%s" % new_data)
         file_values = self.parse_ifcfg(file_data)
@@ -291,7 +292,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         :returns: commands (commands to be run)
         """
 
-        previous_cfg = utils.get_file_data(filename)
+        previous_cfg = common.get_file_data(filename)
         file_values = self.parse_ifcfg(previous_cfg)
         data_values = self.parse_ifcfg(data)
         logger.debug("File values:\n%s" % file_values)
@@ -340,7 +341,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         :return: list of commands to feed to 'ip' to reconfigure routes
         """
 
-        file_values = self.parse_ifcfg_routes(utils.get_file_data(filename))
+        file_values = self.parse_ifcfg_routes(common.get_file_data(filename))
         data_values = self.parse_ifcfg_routes(data)
         route_changes = self.enumerate_ifcfg_route_changes(file_values,
                                                            data_values)
@@ -365,7 +366,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         :return: list of commands to feed to 'ip' to reconfigure route rules
         """
 
-        file_values = self.parse_ifcfg_rules(utils.get_file_data(filename))
+        file_values = self.parse_ifcfg_rules(common.get_file_data(filename))
         data_values = self.parse_ifcfg_rules(data)
         rule_changes = self.enumerate_ifcfg_rule_changes(file_values,
                                                          data_values)
@@ -429,7 +430,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
             data += "TYPE=Infiniband\n"
             data += "PKEY=yes\n"
             data += "PHYSDEV=%s\n" % base_opt.parent
-            data += "PKEY_ID=%s\n" % base_opt.pkey_id
+            data += "PKEY_ID=%d\n" % base_opt.pkey_id
         elif re.match(r'\w+\.\d+$', base_opt.name):
             data += "VLAN=yes\n"
         elif isinstance(base_opt, objects.Interface):
@@ -472,7 +473,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
                 if base_opt.use_dhcp:
                     data += ("OVSDHCPINTERFACES=\"%s\"\n" % " ".join(members))
             if base_opt.primary_interface_name:
-                mac = utils.interface_mac(base_opt.primary_interface_name)
+                mac = common.interface_mac(base_opt.primary_interface_name)
                 ovs_extra.append("set bridge %s other-config:hwaddr=%s" %
                                  (base_opt.name, mac))
             if base_opt.ovs_options:
@@ -516,12 +517,12 @@ class IfcfgNetConfig(os_net_config.NetConfig):
                 self.member_names[base_opt.name] = members
             if base_opt.primary_interface_name:
                 primary_name = base_opt.primary_interface_name
-                primary_mac = utils.interface_mac(primary_name)
+                primary_mac = common.interface_mac(primary_name)
                 data += "MACADDR=\"%s\"\n" % primary_mac
         elif isinstance(base_opt, objects.LinuxBond):
             if base_opt.primary_interface_name:
                 primary_name = base_opt.primary_interface_name
-                primary_mac = utils.interface_mac(primary_name)
+                primary_mac = common.interface_mac(primary_name)
                 data += "MACADDR=\"%s\"\n" % primary_mac
             if base_opt.use_dhcp:
                 data += "BOOTPROTO=dhcp\n"
@@ -533,7 +534,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         elif isinstance(base_opt, objects.LinuxTeam):
             if base_opt.primary_interface_name:
                 primary_name = base_opt.primary_interface_name
-                primary_mac = utils.interface_mac(primary_name)
+                primary_mac = common.interface_mac(primary_name)
                 data += "MACADDR=\"%s\"\n" % primary_mac
             if base_opt.use_dhcp:
                 data += "BOOTPROTO=dhcp\n"
@@ -577,6 +578,14 @@ class IfcfgNetConfig(os_net_config.NetConfig):
                 data += "RX_QUEUE=%i\n" % base_opt.rx_queue
                 ovs_extra.append("set Interface $DEVICE " +
                                  "options:n_rxq=$RX_QUEUE")
+            if base_opt.rx_queue_size:
+                data += "RX_QUEUE_SIZE=%i\n" % base_opt.rx_queue_size
+                ovs_extra.append("set Interface $DEVICE " +
+                                 "options:n_rxq_desc=$RX_QUEUE_SIZE")
+            if base_opt.tx_queue_size:
+                data += "TX_QUEUE_SIZE=%i\n" % base_opt.tx_queue_size
+                ovs_extra.append("set Interface $DEVICE " +
+                                 "options:n_txq_desc=$TX_QUEUE_SIZE")
         elif isinstance(base_opt, objects.OvsDpdkBond):
             ovs_extra.extend(base_opt.ovs_extra)
             # Referring to bug:1643026, the below commenting of the interfaces,
@@ -613,6 +622,17 @@ class IfcfgNetConfig(os_net_config.NetConfig):
                     for member in base_opt.members:
                         ovs_extra.append("set Interface %s options:n_rxq="
                                          "$RX_QUEUE" % member.name)
+                if base_opt.rx_queue_size:
+                    data += "RX_QUEUE_SIZE=%i\n" % base_opt.rx_queue_size
+                    for member in base_opt.members:
+                        ovs_extra.append("set Interface %s options:n_rxq_desc="
+                                         "$RX_QUEUE_SIZE" % member.name)
+                if base_opt.tx_queue_size:
+                    data += "TX_QUEUE_SIZE=%i\n" % base_opt.tx_queue_size
+                    for member in base_opt.members:
+                        ovs_extra.append("set Interface %s options:n_txq_desc="
+                                         "$TX_QUEUE_SIZE" % member.name)
+
             if base_opt.ovs_options:
                 data += "OVS_OPTIONS=\"%s\"\n" % base_opt.ovs_options
             ovs_extra.extend(base_opt.ovs_extra)
@@ -979,6 +999,16 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         logger.debug('ovs dpdk port data: %s' % data)
         self.interface_data[ovs_dpdk_port.name] = data
 
+        """Add an extra ifcfg entry for mellanox NICs,
+        for the interface which is a member of ovs_dpdk_port
+        with NM and DHCP disabled
+        """
+        if common.is_mellanox_interface(ifname):
+            self.nm_controlled = False
+            self.use_dhcp = False
+            dpdk_if_name = objects.Interface(ifname)
+            self.add_interface(dpdk_if_name)
+
     def add_ovs_dpdk_bond(self, ovs_dpdk_bond):
         """Add an OvsDPDKBond object to the net config object.
 
@@ -1003,6 +1033,18 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         if ovs_dpdk_bond.rules:
             self._add_rules(ovs_dpdk_bond.name, ovs_dpdk_bond.rules)
 
+        """Add an extra ifcfg entry for mellanox NICs,
+        for all interfaces which is a member of ovs_dpdk_bond
+        with NM and DHCP disabled
+        """
+        for dpdk_port in ovs_dpdk_bond.members:
+            ifname = dpdk_port.members[0].name
+            if common.is_mellanox_interface(ifname):
+                self.nm_controlled = False
+                self.use_dhcp = False
+                dpdk_if_name = objects.Interface(ifname)
+                self.add_interface(dpdk_if_name)
+
     def add_sriov_pf(self, sriov_pf):
         """Add a SriovPF object to the net config object
 
@@ -1014,7 +1056,8 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         utils.update_sriov_pf_map(sriov_pf.name, sriov_pf.numvfs,
                                   self.noop, promisc=sriov_pf.promisc,
                                   link_mode=sriov_pf.link_mode,
-                                  vdpa=sriov_pf.vdpa)
+                                  vdpa=sriov_pf.vdpa,
+                                  steering_mode=sriov_pf.steering_mode)
         self.interface_data[sriov_pf.name] = data
         if sriov_pf.routes:
             self._add_routes(sriov_pf.name, sriov_pf.routes)
@@ -1046,7 +1089,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         if not vpp_interface.pci_dev:
             vpp_interface.pci_dev = utils.get_stored_pci_address(
                 vpp_interface.name, False)
-        vpp_interface.hwaddr = utils.interface_mac(vpp_interface.name)
+        vpp_interface.hwaddr = common.interface_mac(vpp_interface.name)
         if not self.noop:
             self.ifdown(vpp_interface.name)
             remove_ifcfg_config(vpp_interface.name)
@@ -1070,13 +1113,11 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         """
         logger.info('adding contrail_vrouter interface: %s'
                     % contrail_vrouter.name)
-        # Contrail vrouter will have the only member (of type interface,
-        # vlan or linux_bond)
-        ifname = contrail_vrouter.members[0].name
+        ifnames = ",".join([m.name for m in contrail_vrouter.members])
         data = self._add_common(contrail_vrouter)
         data += "DEVICETYPE=vhost\n"
         data += "TYPE=kernel_mode\n"
-        data += "BIND_INT=%s\n" % ifname
+        data += "BIND_INT=%s\n" % ifnames
         logger.debug('contrail data: %s' % data)
         self.interface_data[contrail_vrouter.name] = data
         if contrail_vrouter.routes:
@@ -1126,6 +1167,12 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         data = self._add_common(linux_tap)
         data += "TYPE=Tap\n"
         self.interface_data[linux_tap.name] = data
+        if linux_tap.routes:
+            self._add_routes(linux_tap.name,
+                             linux_tap.routes)
+        if linux_tap.rules:
+            self._add_rules(linux_tap.name,
+                            linux_tap.rules)
 
     def generate_ivs_config(self, ivs_uplinks, ivs_interfaces):
         """Generate configuration content for ivs."""
@@ -1183,7 +1230,7 @@ class IfcfgNetConfig(os_net_config.NetConfig):
         custom_tables = {}
         res_ids = ['0', '253', '254', '255']
         res_names = ['unspec', 'default', 'main', 'local']
-        rt_config = utils.get_file_data(route_table_config_path()).split('\n')
+        rt_config = common.get_file_data(route_table_config_path()).split('\n')
         rt_defaults = _ROUTE_TABLE_DEFAULT.split("\n")
         data = _ROUTE_TABLE_DEFAULT
         for line in (line for line in rt_config if line not in rt_defaults):
