@@ -23,6 +23,7 @@ import logging
 import netaddr
 from oslo_utils import strutils
 
+from os_net_config import common
 from os_net_config import utils
 
 
@@ -151,7 +152,7 @@ def mapped_nics(nic_mapping=None):
                 # If 'nic' is actually a mac address, retrieve actual nic name
                 for nic in available_nics:
                     try:
-                        mac = utils.interface_mac(nic)
+                        mac = common.interface_mac(nic)
                     except IOError:
                         continue
                     if nic_mapped == mac:
@@ -352,7 +353,7 @@ class _BaseOpts(object):
                 self.name = name
                 self.hwname = '%s%s' % (mapped_nic_names[base_name],
                                         vlan_suffix)
-                self.hwaddr = utils.interface_mac(self.hwname)
+                self.hwaddr = common.interface_mac(self.hwname)
                 self.renamed = True
             else:
                 self.name = '%s%s' % (mapped_nic_names[base_name], vlan_suffix)
@@ -1019,9 +1020,9 @@ class LinuxBond(_BaseOpts):
                         % (iface.device, iface.vfid))
             iface.trust = 'on'
         if iface.spoofcheck is None:
-            logger.info("Spoofcheck is not set for VF %s:%d, defaulting to on"
+            logger.info("Spoofcheck is not set for VF %s:%d, defaulting to off"
                         % (iface.device, iface.vfid))
-            iface.spoofcheck = 'on'
+            iface.spoofcheck = 'off'
         if iface.promisc is None:
             logger.info("Promisc is not set for VF %s:%d, defaulting to off"
                         % (iface.device, iface.vfid))
@@ -1282,20 +1283,16 @@ class IbChildInterface(_BaseOpts):
     def from_json(json):
         parent = _get_required_field(json, 'parent', 'IbChildInterface')
         pkey_id = _get_required_field(json, 'pkey_id', 'IbChildInterface')
-        if type(pkey_id) == str:
+        try:
+            pkey_id = int(pkey_id)
+        except ValueError:
             try:
-                pkey_id = int(pkey_id)
-            except ValueError:
-                try:
-                    pkey_id = int(pkey_id, base=16)
-                except Exception:
-                    # Note (Abdallahyas): We do not care for other
-                    # bases other than decimal and hexa
-                    msg = "pkey only support decimal and hex bases, not int"
-                    raise InvalidConfigException(msg)
-        else:
-            msg = "Invalid pkey type: got %s" % type(pkey_id)
-            raise InvalidConfigException(msg)
+                pkey_id = int(pkey_id, base=16)
+            except Exception:
+                # Note (Abdallahyas): We do not care for other
+                # bases other than base 10 or base 16
+                msg = "pkey only supports base 10 or base 16 int numbers"
+                raise InvalidConfigException(msg)
         if (pkey_id < 0x0001 or pkey_id >= 0x7fff):
             msg = "Invalid pkey value 0x%X" % pkey_id
             raise InvalidConfigException(msg)
@@ -1311,7 +1308,8 @@ class OvsDpdkPort(_BaseOpts):
                  nic_mapping=None, persist_mapping=False, defroute=True,
                  dhclient_args=None, dns_servers=None, nm_controlled=False,
                  onboot=True, domain=None, members=None, driver='vfio-pci',
-                 ovs_options=None, ovs_extra=None, rx_queue=None):
+                 ovs_options=None, ovs_extra=None, rx_queue=None,
+                 rx_queue_size=None, tx_queue_size=None):
 
         check_ovs_installed(self.__class__.__name__)
 
@@ -1326,6 +1324,8 @@ class OvsDpdkPort(_BaseOpts):
         self.ovs_extra = format_ovs_extra(self, ovs_extra)
         self.driver = driver
         self.rx_queue = rx_queue
+        self.rx_queue_size = rx_queue_size
+        self.tx_queue_size = tx_queue_size
 
     @staticmethod
     def update_vf_config(iface):
@@ -1395,6 +1395,8 @@ class OvsDpdkPort(_BaseOpts):
             raise InvalidConfigException(msg)
 
         rx_queue = json.get('rx_queue', None)
+        rx_queue_size = json.get('rx_queue_size', None)
+        tx_queue_size = json.get('tx_queue_size', None)
         ovs_options = json.get('ovs_options', [])
         ovs_options = ['options:%s' % opt for opt in ovs_options]
         ovs_extra = json.get('ovs_extra', [])
@@ -1409,7 +1411,9 @@ class OvsDpdkPort(_BaseOpts):
                            nm_controlled=nm_controlled, onboot=onboot,
                            domain=domain, members=members, driver=driver,
                            ovs_options=ovs_options,
-                           ovs_extra=ovs_extra, rx_queue=rx_queue)
+                           ovs_extra=ovs_extra, rx_queue=rx_queue,
+                           rx_queue_size=rx_queue_size,
+                           tx_queue_size=tx_queue_size)
 
 
 class SriovVF(_BaseOpts):
@@ -1516,7 +1520,7 @@ class SriovPF(_BaseOpts):
                  defroute=True, dhclient_args=None, dns_servers=None,
                  nm_controlled=False, onboot=True, domain=None, members=None,
                  promisc=None, link_mode='legacy', ethtool_opts=None,
-                 vdpa=False):
+                 vdpa=False, steering_mode=None):
         addresses = addresses or []
         routes = routes or []
         rules = rules or []
@@ -1536,6 +1540,7 @@ class SriovPF(_BaseOpts):
         self.link_mode = link_mode
         self.ethtool_opts = ethtool_opts
         self.vdpa = vdpa
+        self.steering_mode = steering_mode
 
     @staticmethod
     def get_on_off(config):
@@ -1556,6 +1561,10 @@ class SriovPF(_BaseOpts):
         link_mode = json.get('link_mode', 'legacy')
         ethtool_opts = json.get('ethtool_opts', None)
         vdpa = json.get('vdpa', False)
+        steering_mode = json.get('steering_mode')
+        if steering_mode is not None and steering_mode not in ['smfs', 'dmfs']:
+            msg = 'Expecting steering_mode to match smfs/dmfs'
+            raise InvalidConfigException(msg)
         if vdpa:
             msg = ""
             if link_mode != 'switchdev':
@@ -1572,7 +1581,7 @@ class SriovPF(_BaseOpts):
         opts = _BaseOpts.base_opts_from_json(json)
         return SriovPF(name, numvfs, *opts, promisc=promisc,
                        link_mode=link_mode, ethtool_opts=ethtool_opts,
-                       vdpa=vdpa)
+                       vdpa=vdpa, steering_mode=steering_mode)
 
 
 class OvsDpdkBond(_BaseOpts):
@@ -1583,7 +1592,8 @@ class OvsDpdkBond(_BaseOpts):
                  members=None, ovs_options=None, ovs_extra=None,
                  nic_mapping=None, persist_mapping=False, defroute=True,
                  dhclient_args=None, dns_servers=None, nm_controlled=False,
-                 onboot=True, domain=None, rx_queue=None):
+                 onboot=True, domain=None, rx_queue=None,
+                 rx_queue_size=None, tx_queue_size=None):
 
         check_ovs_installed(self.__class__.__name__)
 
@@ -1597,6 +1607,8 @@ class OvsDpdkBond(_BaseOpts):
         self.ovs_options = ovs_options
         self.ovs_extra = format_ovs_extra(self, ovs_extra)
         self.rx_queue = rx_queue
+        self.rx_queue_size = rx_queue_size
+        self.tx_queue_size = tx_queue_size
 
         for member in self.members:
             if member.primary:
@@ -1620,6 +1632,8 @@ class OvsDpdkBond(_BaseOpts):
          onboot, domain) = _BaseOpts.base_opts_from_json(
              json, include_primary=False)
         rx_queue = json.get('rx_queue', None)
+        rx_queue_size = json.get('rx_queue_size', None)
+        tx_queue_size = json.get('tx_queue_size', None)
         ovs_options = json.get('ovs_options')
         ovs_extra = json.get('ovs_extra', [])
         if not isinstance(ovs_extra, list):
@@ -1652,7 +1666,9 @@ class OvsDpdkBond(_BaseOpts):
                            defroute=defroute, dhclient_args=dhclient_args,
                            dns_servers=dns_servers,
                            nm_controlled=nm_controlled, onboot=onboot,
-                           domain=domain, rx_queue=rx_queue)
+                           domain=domain, rx_queue=rx_queue,
+                           rx_queue_size=rx_queue_size,
+                           tx_queue_size=tx_queue_size)
 
 
 class VppInterface(_BaseOpts):
