@@ -14,17 +14,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from io import StringIO
 import os.path
 import random
+import re
 import sys
 import yaml
 
 import os_net_config
 from os_net_config import cli
-from os_net_config import sriov_config
+from os_net_config import common
 from os_net_config.tests import base
-from os_net_config import utils
-import six
 
 
 REALPATH = os.path.dirname(os.path.realpath(__file__))
@@ -37,7 +37,10 @@ class TestCli(base.TestCase):
     def setUp(self):
         super(TestCli, self).setUp()
         rand = str(int(random.random() * 100000))
-        sriov_config._SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
+        common.SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
+        common._LOG_FILE = '/tmp/' + rand + 'os_net_config.log'
+        sys.stdout = StringIO()
+        sys.stderr = StringIO()
 
         def stub_is_ovs_installed():
             return True
@@ -46,24 +49,22 @@ class TestCli(base.TestCase):
 
     def tearDown(self):
         super(TestCli, self).tearDown()
-        if os.path.isfile(sriov_config._SRIOV_CONFIG_FILE):
-            os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        if os.path.isfile(common._LOG_FILE):
+            os.remove(common._LOG_FILE)
+        if os.path.isfile(common.SRIOV_CONFIG_FILE):
+            os.remove(common.SRIOV_CONFIG_FILE)
 
     def run_cli(self, argstr, exitcodes=(0,)):
-        orig = sys.stdout
-        orig_stderr = sys.stderr
-
-        sys.stdout = six.StringIO()
-        sys.stderr = six.StringIO()
+        for s in [sys.stdout, sys.stderr]:
+            s.flush()
+            s.truncate(0)
+            s.seek(0)
         ret = cli.main(argstr.split())
         self.assertIn(ret, exitcodes)
-
+        sys.stdout.flush()
+        sys.stderr.flush()
         stdout = sys.stdout.getvalue()
-        sys.stdout.close()
-        sys.stdout = orig
         stderr = sys.stderr.getvalue()
-        sys.stderr.close()
-        sys.stderr = orig_stderr
         return (stdout, stderr)
 
     def stub_get_stored_pci_address(self, ifname, noop):
@@ -222,7 +223,7 @@ class TestCli(base.TestCase):
                       test_get_vf_devname)
         self.stub_out('os_net_config.utils.get_pci_address',
                       test_get_pci_address)
-        self.stub_out('os_net_config.utils.interface_mac',
+        self.stub_out('os_net_config.common.interface_mac',
                       test_interface_mac)
         ivs_yaml = os.path.join(SAMPLE_BASE, 'sriov_pf.yaml')
         ivs_json = os.path.join(SAMPLE_BASE, 'sriov_pf.json')
@@ -230,14 +231,14 @@ class TestCli(base.TestCase):
                                            '--exit-on-validation-errors '
                                            '-c %s' % ivs_yaml)
         self.assertEqual('', stderr)
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         sriov_config_yaml = yaml.safe_load(contents)
-        os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        os.remove(common.SRIOV_CONFIG_FILE)
         stdout_json, stderr = self.run_cli('ARG0 --provider=ifcfg --noop '
                                            '--exit-on-validation-errors '
                                            '-c %s' % ivs_json)
         self.assertEqual('', stderr)
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         sriov_config_json = yaml.safe_load(contents)
         sanity_devices = ['DEVICE=p2p1',
                           'DEVICE=p2p1_5',
@@ -267,14 +268,14 @@ class TestCli(base.TestCase):
                                            '--exit-on-validation-errors '
                                            '-c %s' % ivs_yaml)
         self.assertEqual('', stderr)
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         sriov_config_yaml = yaml.safe_load(contents)
-        os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        os.remove(common.SRIOV_CONFIG_FILE)
         stdout_json, stderr = self.run_cli('ARG0 --provider=ifcfg --noop '
                                            '--exit-on-validation-errors '
                                            '-c %s' % ivs_json)
         self.assertEqual('', stderr)
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         sriov_config_json = yaml.safe_load(contents)
         sanity_devices = ['DEVICE=p2p1',
                           'DEVICE=p2p1_5',
@@ -420,6 +421,11 @@ class TestCli(base.TestCase):
         self.assertEqual(stdout_yaml, stdout_json)
 
     def test_contrail_vrouter_dpdk_noop_output(self):
+        timestamp_rex = re.compile(
+            (r'contrail_vrouter_dpdk\.(yaml|json)|^[\d]{4}-[\d]{2}-[\d]{2} '
+             r'[\d]{2}:[\d]{2}:[\d]{2}\.[\d]{3} '),
+            flags=re.M
+        )
         cvi_yaml = os.path.join(SAMPLE_BASE, 'contrail_vrouter_dpdk.yaml')
         cvi_json = os.path.join(SAMPLE_BASE, 'contrail_vrouter_dpdk.json')
         self.stub_out('os_net_config.utils.get_stored_pci_address',
@@ -440,4 +446,6 @@ class TestCli(base.TestCase):
                           'TYPE=dpdk']
         for dev in sanity_devices:
             self.assertIn(dev, stdout_yaml)
+        stdout_yaml = timestamp_rex.sub('', stdout_yaml)
+        stdout_json = timestamp_rex.sub('', stdout_json)
         self.assertEqual(stdout_yaml, stdout_json)
