@@ -17,13 +17,11 @@
 import json
 import os
 import random
-import six
 import yaml
 
+from os_net_config import common
 from os_net_config import objects
-from os_net_config import sriov_config
 from os_net_config.tests import base
-from os_net_config import utils
 
 
 class TestRoute(base.TestCase):
@@ -414,7 +412,7 @@ class TestBridge(base.TestCase):
     def setUp(self):
         super(TestBridge, self).setUp()
         rand = str(int(random.random() * 100000))
-        sriov_config._SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
+        common.SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
 
         def stub_is_ovs_installed():
             return True
@@ -423,8 +421,8 @@ class TestBridge(base.TestCase):
 
     def tearDown(self):
         super(TestBridge, self).tearDown()
-        if os.path.isfile(sriov_config._SRIOV_CONFIG_FILE):
-            os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        if os.path.isfile(common.SRIOV_CONFIG_FILE):
+            os.remove(common.SRIOV_CONFIG_FILE)
 
     def test_from_json_dhcp(self):
         data = """{
@@ -485,7 +483,7 @@ class TestBridge(base.TestCase):
         self.assertTrue(interface1.ovs_port)
         self.assertEqual("br-foo", interface1.bridge_name)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -550,7 +548,7 @@ class TestBridge(base.TestCase):
         self.assertEqual("em2", interface2.device)
         self.assertEqual("br-foo", bond.bridge_name)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -613,7 +611,7 @@ class TestBridge(base.TestCase):
 
         objects.object_from_json(json.loads(data))
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -660,7 +658,7 @@ class TestBridge(base.TestCase):
         self.assertTrue(interface1.ovs_port)
         self.assertEqual("br-foo", interface1.bridge_name)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -711,7 +709,7 @@ class TestBridge(base.TestCase):
         self.assertFalse(dpdk_interface.ovs_port)
         self.assertEqual("br-foo", dpdk_interface.bridge_name)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -767,7 +765,7 @@ class TestBridge(base.TestCase):
         self.assertFalse(dpdk_interface.ovs_port)
         self.assertEqual("br-foo", dpdk_interface.bridge_name)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -987,7 +985,7 @@ class TestIvsInterface(base.TestCase):
                                 objects.IvsBridge.from_json,
                                 json.loads(data))
         expected = 'IVS does not support bond interfaces.'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
 
 class TestNfvswitchBridge(base.TestCase):
@@ -1052,7 +1050,7 @@ class TestNfvswitchInterface(base.TestCase):
                                 objects.NfvswitchBridge.from_json,
                                 json.loads(data))
         expected = 'NFVSwitch does not support bond interfaces.'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
 
 class TestBond(base.TestCase):
@@ -1160,7 +1158,7 @@ class TestLinuxBond(base.TestCase):
     def setUp(self):
         super(TestLinuxBond, self).setUp()
         rand = str(int(random.random() * 100000))
-        sriov_config._SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
+        common.SRIOV_CONFIG_FILE = '/tmp/sriov_config_' + rand + '.yaml'
 
         def stub_is_ovs_installed():
             return True
@@ -1169,8 +1167,8 @@ class TestLinuxBond(base.TestCase):
 
     def tearDown(self):
         super(TestLinuxBond, self).tearDown()
-        if os.path.isfile(sriov_config._SRIOV_CONFIG_FILE):
-            os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        if os.path.isfile(common.SRIOV_CONFIG_FILE):
+            os.remove(common.SRIOV_CONFIG_FILE)
 
     def test_from_json_dhcp(self):
         data = """{
@@ -1257,14 +1255,14 @@ class TestLinuxBond(base.TestCase):
                      'vlan_id': 111, 'qos': 1,
                      'min_tx_rate': 0, 'max_tx_rate': 10,
                      'pci_address': '0000:79:10.1',
-                     'spoofcheck': 'on', 'trust': 'on',
+                     'spoofcheck': 'off', 'trust': 'on',
                      'promisc': 'off'},
                     {'device_type': 'vf', 'name': 'em2_1',
                      'device': {'name': 'em2', 'vfid': 1},
                      'vlan_id': 111, 'qos': 1,
                      'min_tx_rate': 0, 'max_tx_rate': 10,
                      'pci_address': '0000:79:10.2',
-                     'spoofcheck': 'on', 'trust': 'on',
+                     'spoofcheck': 'off', 'trust': 'on',
                      'promisc': 'off'}]
 
         def test_get_vf_devname(device, vfid):
@@ -1289,7 +1287,7 @@ class TestLinuxBond(base.TestCase):
         self.assertEqual("em1", interface1.device)
         self.assertEqual("em2", interface2.device)
 
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -1351,7 +1349,7 @@ class TestLinuxBond(base.TestCase):
                       test_get_pci_address)
 
         objects.object_from_json(json.loads(data))
-        contents = utils.get_file_data(sriov_config._SRIOV_CONFIG_FILE)
+        contents = common.get_file_data(common.SRIOV_CONFIG_FILE)
         vf_map = yaml.safe_load(contents) if contents else []
         self.assertListEqual(vf_final, vf_map)
 
@@ -1624,21 +1622,14 @@ class TestIbChildInterface(base.TestCase):
         ib_child_interface = objects.IbChildInterface('foo', pkey_id=100)
         self.assertEqual(100, ib_child_interface.pkey_id)
 
-    def test_ib_child_interface_pkek_id_str(self):
-        data = '{"type": "ib_child_interface", ' \
-               '"parent": "foo", "pkey_id": "100"}'
-        ib_child_interface = \
-            objects.IbChildInterface.from_json(json.loads(data))
-        self.assertEqual(100, ib_child_interface.pkey_id)
-
-    def test_ib_child_interface_pkey_id_str_hexa(self):
+    def test_ib_child_interface_pkey_id_hexa(self):
         data = '{"type": "ib_child_interface", ' \
                '"parent": "foo", "pkey_id": "0x64"}'
         ib_child_interface = \
             objects.IbChildInterface.from_json(json.loads(data))
         self.assertEqual(100, ib_child_interface.pkey_id)
 
-    def test_ib_child_interface_pkey_id_str_invalid_base(self):
+    def test_ib_child_interface_pkey_id_invalid_base(self):
         data = '{"type": "ib_child_interface", ' \
                '"parent": "foo", "pkey_id": "0b01100100"}'
         self.assertRaises(objects.InvalidConfigException,
@@ -1647,14 +1638,14 @@ class TestIbChildInterface(base.TestCase):
 
     def test_ib_child_interface_nm_controlled_true(self):
         data = '{"type": "ib_child_interface", ' \
-               '"parent": "foo", "pkey_id": "100"}'
+               '"parent": "foo", "pkey_id": 100}'
         ib_child_interface = \
             objects.IbChildInterface.from_json(json.loads(data))
         self.assertEqual(True, ib_child_interface.nm_controlled)
 
     def test_ib_child_interface_pkey_id_zero(self):
         data = '{"type": "ib_child_interface", ' \
-               '"parent": "foo", "pkey_id": "0"}'
+               '"parent": "foo", "pkey_id": 0}'
         self.assertRaises(objects.InvalidConfigException,
                           objects.object_from_json,
                           json.loads(data))
@@ -1746,7 +1737,7 @@ class TestNicMapping(base.TestCase):
         err = self.assertRaises(objects.InvalidConfigException,
                                 objects.mapped_nics, nic_mapping=mapping)
         expected = 'em1 already mapped, check mapping file for duplicates'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_mapped_nics_map_invalid_nic(self):
         self._stub_active_nics(['em1'])
@@ -1760,7 +1751,8 @@ class TestNicMapping(base.TestCase):
             mac_map = {'em1': '12:34:56:78:9a:bc',
                        'em2': '12:34:56:de:f0:12'}
             return mac_map[name]
-        self.stub_out('os_net_config.utils.interface_mac', dummy_interface_mac)
+        self.stub_out('os_net_config.common.interface_mac',
+                      dummy_interface_mac)
         self._stub_active_nics(['em1', 'em2'])
         self._stub_available_nics(['em1', 'em2'])
         mapping = {'nic1': '12:34:56:de:f0:12', 'nic2': '12:34:56:78:9a:bc'}
@@ -1773,7 +1765,8 @@ class TestNicMapping(base.TestCase):
                        'em2': '12:34:56:de:f0:12'}
             return mac_map[name]
 
-        self.stub_out('os_net_config.utils.interface_mac', dummy_interface_mac)
+        self.stub_out('os_net_config.common.interface_mac',
+                      dummy_interface_mac)
         self._stub_active_nics(['em1', 'em2'])
         self._stub_available_nics(['em1', 'em2'])
         mapping = {'nic1': '12:34:56:de:f0:12', 'nic2': 'aa:bb:cc:dd:ee:ff'}
@@ -1799,7 +1792,7 @@ class TestNicMapping(base.TestCase):
         err = self.assertRaises(objects.InvalidConfigException,
                                 objects.mapped_nics, nic_mapping=mapping)
         expected = 'cannot map em2 to alias em1, alias overlaps'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_mapped_nics_mapping_inactive_name_as_alias(self):
         def dummy_is_active_nic(nic):
@@ -1982,7 +1975,7 @@ class TestSriovPF(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Expecting link_mode to match legacy/switchdev'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_vdpa_link_mode_invalid(self):
         data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 8,' \
@@ -1992,7 +1985,7 @@ class TestSriovPF(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Expecting link_mode to be switchdev when vdpa is enabled'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_vdpa_no_numvfs(self):
         data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 0,' \
@@ -2002,7 +1995,53 @@ class TestSriovPF(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Expecting to have at least 1 numvfs when vdpa is enabled'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
+
+    def test_from_json_steering_mode_dmfs(self):
+        data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 8,' \
+               '"use_dhcp": false, "promisc": false, "link_mode":' \
+               '"switchdev", "steering_mode": "dmfs"}'
+        pf = objects.object_from_json(json.loads(data))
+        self.assertEqual("p6p1", pf.name)
+        self.assertEqual(8, pf.numvfs)
+        self.assertEqual("off", pf.promisc)
+        self.assertFalse(pf.use_dhcp)
+        self.assertEqual("switchdev", pf.link_mode)
+        self.assertEqual("dmfs", pf.steering_mode)
+
+    def test_from_json_steering_mode_smfs(self):
+        data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 8,' \
+               '"use_dhcp": false, "promisc": false, "link_mode":' \
+               '"switchdev", "steering_mode": "smfs"}'
+        pf = objects.object_from_json(json.loads(data))
+        self.assertEqual("p6p1", pf.name)
+        self.assertEqual(8, pf.numvfs)
+        self.assertEqual("off", pf.promisc)
+        self.assertFalse(pf.use_dhcp)
+        self.assertEqual("switchdev", pf.link_mode)
+        self.assertEqual("smfs", pf.steering_mode)
+
+    def test_from_json_steering_mode_none(self):
+        data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 8,' \
+               '"use_dhcp": false, "promisc": false, "link_mode":' \
+               '"switchdev"}'
+        pf = objects.object_from_json(json.loads(data))
+        self.assertEqual("p6p1", pf.name)
+        self.assertEqual(8, pf.numvfs)
+        self.assertEqual("off", pf.promisc)
+        self.assertFalse(pf.use_dhcp)
+        self.assertEqual("switchdev", pf.link_mode)
+        self.assertIsNone(pf.steering_mode)
+
+    def test_from_json_steering_mode_invalid(self):
+        data = '{"type": "sriov_pf", "name": "p6p1", "numvfs": 8,' \
+               '"use_dhcp": false, "promisc": false, "link_mode":' \
+               '"switchdev", "steering_mode": "dmfss"}'
+        err = self.assertRaises(objects.InvalidConfigException,
+                                objects.object_from_json,
+                                json.loads(data))
+        expected = 'Expecting steering_mode to match smfs/dmfs'
+        self.assertIn(expected, str(err))
 
     def test_from_json_ethtool_opts(self):
         data = '{"type": "sriov_pf", "name": "em1", "numvfs": 16, ' \
@@ -2054,7 +2093,7 @@ class TestSriovVF(base.TestCase):
                                 json.loads(data))
         expected = 'SriovVF JSON objects require \'vfid\' to be configured ' \
                    'as %s' % (str(int))
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_no_vfid(self):
         def test_get_vf_devname(device, vfid):
@@ -2073,7 +2112,7 @@ class TestSriovVF(base.TestCase):
                                 json.loads(data))
         expected = 'SriovVF JSON objects require \'vfid\' to be configured ' \
                    'as %s' % (str(int))
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_vfid(self):
         def test_get_vf_devname(device, vfid):
@@ -2191,7 +2230,7 @@ class TestSriovVF(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Expecting state to match auto/enable/disable'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_vfid_invalid_qos(self):
         def test_get_vf_devname(device, vfid):
@@ -2212,7 +2251,7 @@ class TestSriovVF(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Vlan tag not set for QOS - VF: em4:16'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_from_json_vfid_nic1(self):
         def test_get_vf_devname(device, vfid):
@@ -2392,7 +2431,7 @@ class TestVppBond(base.TestCase):
                                 objects.object_from_json,
                                 json.loads(data))
         expected = 'Members must be of type vpp_interface'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
 
 class TestOvsRequiredObjects(base.TestCase):
@@ -2424,7 +2463,7 @@ class TestOvsRequiredObjects(base.TestCase):
                                 objects.OvsBond.from_json,
                                 json.loads(data))
         expected = 'OvsBond cannot be created as OpenvSwitch is not installed.'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_ovs_bridge(self):
         data = """{
@@ -2445,7 +2484,7 @@ class TestOvsRequiredObjects(base.TestCase):
                                 json.loads(data))
         expected = 'OvsBridge cannot be created as OpenvSwitch is not ' \
                    'installed.'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
     def test_dpdk_port(self):
         data = """{
@@ -2462,7 +2501,7 @@ class TestOvsRequiredObjects(base.TestCase):
                                 json.loads(data))
         expected = 'OvsDpdkPort cannot be created as OpenvSwitch is not ' \
                    'installed.'
-        self.assertIn(expected, six.text_type(err))
+        self.assertIn(expected, str(err))
 
 
 class TestLinuxTap(base.TestCase):
