@@ -18,25 +18,15 @@ import glob
 import logging
 import os
 import re
-import six
 import time
 import yaml
 
+from os_net_config import common
 from os_net_config import sriov_config
 from oslo_concurrency import processutils
 
 logger = logging.getLogger(__name__)
-_SYS_CLASS_NET = '/sys/class/net'
 _SYS_BUS_PCI_DEV = '/sys/bus/pci/devices'
-# File to contain the DPDK mapped nics, as nic name will not be available after
-# binding driver, which is required for correct nic numbering.
-# Format of the file (list mapped nic's details):
-#   -
-#     name: eth1
-#     pci_address: 0000:02:00.0
-#     mac_address: 01:02:03:04:05:06
-#     driver: vfio-pci
-_DPDK_MAPPING_FILE = '/var/lib/os-net-config/dpdk_mapping.yaml'
 # sriov_config service shall be created and enabled so that the various
 # SR-IOV PF and VF configurations shall be done during reboot as well using
 # sriov_config.py installed in path /usr/bin/os-net-config-sriov
@@ -96,40 +86,6 @@ def ensure_directory_presence(filepath):
         os.makedirs(dir_path)
 
 
-def get_file_data(filename):
-    if not os.path.exists(filename):
-        return ''
-
-    try:
-        with open(filename, 'r') as f:
-            return f.read()
-    except IOError:
-        logger.error("Error reading file: %s" % filename)
-        return ''
-
-
-def interface_mac(name):
-    try:  # If the iface is part of a Linux bond, the real MAC is only here.
-        with open(_SYS_CLASS_NET + '/%s/bonding_slave/perm_hwaddr' % name,
-                  'r') as f:
-            return f.read().rstrip()
-    except IOError:
-        pass  # Iface is not part of a bond, continue
-
-    try:
-        with open(_SYS_CLASS_NET + '/%s/address' % name, 'r') as f:
-            return f.read().rstrip()
-    except IOError:
-        # If the interface is bound to a DPDK driver, get the mac address from
-        # the DPDK mapping file as /sys files will be removed after binding.
-        dpdk_mac_address = _get_dpdk_mac_address(name)
-        if dpdk_mac_address:
-            return dpdk_mac_address
-
-        logger.error("Unable to read mac address: %s" % name)
-        raise
-
-
 def is_active_nic(interface_name):
     return _is_available_nic(interface_name, True)
 
@@ -138,12 +94,12 @@ def is_real_nic(interface_name):
     if interface_name == 'lo':
         return True
 
-    device_dir = _SYS_CLASS_NET + '/%s/device' % interface_name
+    device_dir = common.get_dev_path(interface_name, '_device')
     has_device_dir = os.path.isdir(device_dir)
 
     address = None
     try:
-        with open(_SYS_CLASS_NET + '/%s/address' % interface_name, 'r') as f:
+        with open(common.get_dev_path(interface_name, "_address"), 'r') as f:
             address = f.read().rstrip()
     except IOError:
         return False
@@ -156,7 +112,7 @@ def is_real_nic(interface_name):
 
 def _is_vf(pci_address):
 
-    # If DPDK drivers are bound on a VF, then the path _SYS_CLASS_NET
+    # If DPDK drivers are bound on a VF, then the path common.SYS_CLASS_NET
     # wouldn't exist. Instead we look for the path
     # /sys/bus/pci/devices/<PCI addr>/physfn to understand if the device
     # is actually a VF. This path could be used by VFs not bound with
@@ -168,10 +124,10 @@ def _is_vf(pci_address):
 
 
 def _is_vf_by_name(interface_name, check_mapping_file=False):
-    vf_path_check = _SYS_CLASS_NET + '/%s/device/physfn' % interface_name
+    vf_path_check = common.get_dev_path(interface_name, 'physfn')
     is_sriov_vf = os.path.isdir(vf_path_check)
     if not is_sriov_vf and check_mapping_file:
-        sriov_map = _get_sriov_map()
+        sriov_map = common.get_sriov_map()
         for item in sriov_map:
             if (item['name'] == interface_name and
                     item['device_type'] == 'vf'):
@@ -188,7 +144,8 @@ def _is_available_nic(interface_name, check_active=True):
             return False
 
         operstate = None
-        with open(_SYS_CLASS_NET + '/%s/operstate' % interface_name, 'r') as f:
+        with open(common.get_dev_path(interface_name, '_operstate'),
+                  'r') as f:
             operstate = f.read().rstrip().lower()
         if check_active and operstate != 'up':
             return False
@@ -232,8 +189,8 @@ def _ordered_nics(check_active):
     embedded_nics = []
     nics = []
     logger.info("Finding active nics")
-    for name in glob.iglob(_SYS_CLASS_NET + '/*'):
-        nic = name[(len(_SYS_CLASS_NET) + 1):]
+    for name in glob.iglob(common.SYS_CLASS_NET + '/*'):
+        nic = name[(len(common.SYS_CLASS_NET) + 1):]
         if _is_available_nic(nic, check_active):
             if _is_embedded_nic(nic):
                 logger.info("%s is an embedded active nic" % nic)
@@ -246,7 +203,7 @@ def _ordered_nics(check_active):
 
     # Adding nics which are bound to DPDK as it will not be found in '/sys'
     # after it is bound to DPDK driver.
-    contents = get_file_data(_DPDK_MAPPING_FILE)
+    contents = common.get_file_data(common.DPDK_MAPPING_FILE)
     if contents:
         dpdk_map = yaml.safe_load(contents)
         for item in dpdk_map:
@@ -267,7 +224,7 @@ def _ordered_nics(check_active):
                     nics.append(nic)
     else:
         logger.info("No DPDK mapping available in path (%s)" %
-                    _DPDK_MAPPING_FILE)
+                    common.DPDK_MAPPING_FILE)
 
     # NOTE: we could just natural sort all active devices,
     # but this ensures em, eno, and eth are ordered first
@@ -279,7 +236,7 @@ def _ordered_nics(check_active):
 
 
 def diff(filename, data):
-    file_data = get_file_data(filename)
+    file_data = common.get_file_data(filename)
     logger.debug("Diff file data:\n%s" % file_data)
     logger.debug("Diff data:\n%s" % data)
     # convert to string as JSON may have unicode in it
@@ -287,6 +244,11 @@ def diff(filename, data):
 
 
 def bind_dpdk_interfaces(ifname, driver, noop):
+    if common.is_mellanox_interface(ifname) and 'vfio-pci' in driver:
+        msg = ("For Mellanox NIC %s, the default driver vfio-pci "
+               "needs to be overridden" % ifname)
+        raise OvsDpdkBindException(msg)
+
     iface_driver = get_interface_driver(ifname)
     if iface_driver == driver:
         logger.info("Driver (%s) is already bound to the device (%s)" %
@@ -304,8 +266,8 @@ def bind_dpdk_interfaces(ifname, driver, noop):
                     msg = "Failed to modprobe vfio-pci module"
                     raise OvsDpdkBindException(msg)
 
-            mac_address = interface_mac(ifname)
-            vendor_id = get_vendor_id(ifname)
+            mac_address = common.interface_mac(ifname)
+            vendor_id = common.get_vendor_id(ifname)
             try:
                 out, err = processutils.execute('driverctl', 'set-override',
                                                 pci_address, driver)
@@ -322,7 +284,7 @@ def bind_dpdk_interfaces(ifname, driver, noop):
                     # - get_dpdk_devargs() in case of OvsDpdkPort and
                     #   OvsDpdkBond.
                     # - bind_dpdk_interface() in case of OvsDpdkBond.
-                    if vendor_id == "0x15b3":
+                    if vendor_id == common.MLNX_VENDOR_ID:
                         processutils.execute('ethtool', '-i', ifname,
                                              attempts=10)
 
@@ -378,34 +340,14 @@ def translate_ifname_to_pci_address(ifname, noop):
     pci_address = get_stored_pci_address(ifname, noop)
     if pci_address is None and not noop:
         pci_address = get_pci_address(ifname, noop=False)
-        mac_address = interface_mac(ifname)
+        mac_address = common.interface_mac(ifname)
         _update_dpdk_map(ifname, pci_address, mac_address, driver=None)
     return pci_address
 
 
-def get_vendor_id(ifname):
-    try:
-        with open('%s/%s/device/vendor' % (_SYS_CLASS_NET, ifname),
-                  'r') as f:
-            out = f.read().strip()
-        return out
-    except IOError:
-        return
-
-
-def get_device_id(ifname):
-    try:
-        with open('%s/%s/device/device' % (_SYS_CLASS_NET, ifname),
-                  'r') as f:
-            out = f.read().strip()
-        return out
-    except IOError:
-        return
-
-
 def get_interface_driver(ifname):
     try:
-        uevent = '%s/%s/device/uevent' % (_SYS_CLASS_NET, ifname)
+        uevent = common.get_dev_path(ifname, 'device/uevent')
         with open(uevent, 'r') as f:
             out = f.read().strip()
             for line in out.split('\n'):
@@ -419,8 +361,8 @@ def get_interface_driver(ifname):
 
 def get_dpdk_devargs(ifname, noop):
     if not noop:
-        vendor_id = get_vendor_id(ifname)
-        device_id = get_device_id(ifname)
+        vendor_id = common.get_vendor_id(ifname)
+        device_id = common.get_device_id(ifname)
         if vendor_id == "0x15b3":
             logger.info("Getting devargs for Mellanox cards")
             if device_id == "0x1007":
@@ -428,7 +370,7 @@ def get_dpdk_devargs(ifname, noop):
                 # address associated with multiple ports. Using a PCI
                 # device won’t work. Instead, we should use
                 # "class=eth,mac=<MAC>"
-                dpdk_devargs = "class=eth,mac=%s" % interface_mac(ifname)
+                dpdk_devargs = f"class=eth,mac={common.interface_mac(ifname)}"
             elif is_active_nic(ifname):
                 # Other Mellanox devices are active and they are not stored
                 # in dpdk_mapping.yaml file, so we need to get their pci
@@ -439,7 +381,6 @@ def get_dpdk_devargs(ifname, noop):
                 # be treated the same as VFs of other devices
                 dpdk_devargs = get_pci_address(ifname, noop)
             else:
-                logger.error("Unable to get devargs for interface %s" % ifname)
                 msg = ("Unable to get devargs for interface %s" % ifname)
                 raise InvalidInterfaceException(msg)
         else:
@@ -452,7 +393,7 @@ def get_dpdk_devargs(ifname, noop):
 # Once the interface is bound to a DPDK driver, all the references to the
 # interface including '/sys' and '/proc', will be removed. And there is no
 # way to identify the nic name after it is bound. So, the DPDK bound nic info
-# is stored persistently in _DPDK_MAPPING_FILE and is used to for nic numbering
+# is stored persistently in DPDK_MAPPING_FILE and is used to for nic numbering
 # on subsequent runs of os-net-config.
 def _update_dpdk_map(ifname, pci_address, mac_address, driver):
     dpdk_map = _get_dpdk_map()
@@ -470,31 +411,23 @@ def _update_dpdk_map(ifname, pci_address, mac_address, driver):
         new_item['driver'] = driver
         dpdk_map.append(new_item)
 
-    write_yaml_config(_DPDK_MAPPING_FILE, dpdk_map)
+    write_yaml_config(common.DPDK_MAPPING_FILE, dpdk_map)
 
 
 def _get_dpdk_map():
-    contents = get_file_data(_DPDK_MAPPING_FILE)
+    contents = common.get_file_data(common.DPDK_MAPPING_FILE)
     dpdk_map = yaml.safe_load(contents) if contents else []
     return dpdk_map
 
 
-def _get_dpdk_mac_address(name):
-    contents = get_file_data(_DPDK_MAPPING_FILE)
-    dpdk_map = yaml.safe_load(contents) if contents else []
-    for item in dpdk_map:
-        if item['name'] == name:
-            return item['mac_address']
-
-
 def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
-                        link_mode='legacy', vdpa=False):
+                        link_mode='legacy', vdpa=False, steering_mode=None):
     if not noop:
         cur_numvfs = sriov_config.get_numvfs(ifname)
         if cur_numvfs > 0 and cur_numvfs != numvfs:
             msg = ("Can't change the numvfs for %s" % ifname)
             raise sriov_config.SRIOVNumvfsException(msg)
-        sriov_map = _get_sriov_map()
+        sriov_map = common.get_sriov_map()
         for item in sriov_map:
             if item['device_type'] == 'pf' and item['name'] == ifname:
                 item['numvfs'] = numvfs
@@ -502,6 +435,8 @@ def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
                 if promisc is not None:
                     item['promisc'] = promisc
                 item['link_mode'] = link_mode
+                if steering_mode is not None:
+                    item['steering_mode'] = steering_mode
                 break
         else:
             new_item = {}
@@ -512,15 +447,11 @@ def update_sriov_pf_map(ifname, numvfs, noop, promisc=None,
             if promisc is not None:
                 new_item['promisc'] = promisc
             new_item['link_mode'] = link_mode
+            if steering_mode is not None:
+                new_item['steering_mode'] = steering_mode
             sriov_map.append(new_item)
 
-        write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, sriov_map)
-
-
-def _get_sriov_map():
-    contents = get_file_data(sriov_config._SRIOV_CONFIG_FILE)
-    sriov_map = yaml.safe_load(contents) if contents else []
-    return sriov_map
+        write_yaml_config(common.SRIOV_CONFIG_FILE, sriov_map)
 
 
 def _set_vf_fields(vf_name, vlan_id, qos, spoofcheck, trust, state, macaddr,
@@ -547,7 +478,7 @@ def _set_vf_fields(vf_name, vlan_id, qos, spoofcheck, trust, state, macaddr,
 
 
 def _clear_empty_values(vf_config):
-    for (key, val) in list(six.iteritems(vf_config)):
+    for (key, val) in list(vf_config.items()):
         if val is None:
             del vf_config[key]
 
@@ -556,7 +487,7 @@ def update_sriov_vf_map(pf_name, vfid, vf_name, vlan_id=0, qos=0,
                         spoofcheck=None, trust=None, state=None, macaddr=None,
                         promisc=None, pci_address=None,
                         min_tx_rate=0, max_tx_rate=0):
-    sriov_map = _get_sriov_map()
+    sriov_map = common.get_sriov_map()
     for item in sriov_map:
         if (item['device_type'] == 'vf' and
            item['device'].get('name') == pf_name and
@@ -576,11 +507,11 @@ def update_sriov_vf_map(pf_name, vfid, vf_name, vlan_id=0, qos=0,
         _clear_empty_values(new_item)
         sriov_map.append(new_item)
 
-    write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, sriov_map)
+    write_yaml_config(common.SRIOV_CONFIG_FILE, sriov_map)
 
 
 def _get_vf_name_from_map(pf_name, vfid):
-    sriov_map = _get_sriov_map()
+    sriov_map = common.get_sriov_map()
     for item in sriov_map:
         if (item['device_type'] == 'vf' and
            item['device'].get('name') == pf_name and
@@ -588,6 +519,32 @@ def _get_vf_name_from_map(pf_name, vfid):
             return item['name']
 
 
+def nicpart_udev_rules_check():
+    """Clean-up UDEV rules on initial deployment
+
+     After writing sriov_config.yaml file, clean-up
+     UDEV rule(s) of PF for which VFs are used by host
+    """
+    if not os.path.exists(sriov_config._UDEV_LEGACY_RULE_FILE):
+        return
+
+    udev = '^KERNEL=="(.*)", RUN.*'
+    udev_reg = re.compile(udev, 0)
+
+    with open(sriov_config._UDEV_LEGACY_RULE_FILE, "r") as fp:
+        rules = fp.readlines()
+
+    with open(sriov_config._UDEV_LEGACY_RULE_FILE, "w") as fp:
+        for line in rules:
+            match = udev_reg.match(line)
+            if match:
+                dev_name = match.group(1)
+                if not sriov_config.is_partitioned_pf(dev_name):
+                    fp.write(line)
+            else:
+                fp.write(line)
+
+
 def _configure_sriov_config_service():
     """Generate the sriov_config.service
 
@@ -609,11 +566,11 @@ def configure_sriov_pfs(execution_from_cli=False, restart_openvswitch=False):
 def configure_sriov_vfs():
     logger.info("Configuring VFs now")
     sriov_config.configure_sriov_vf()
+    nicpart_udev_rules_check()
 
 
 def get_vf_devname(pf_name, vfid):
-    vf_path = os.path.join(_SYS_CLASS_NET, pf_name, "device/virtfn%d/net"
-                           % vfid)
+    vf_path = common.get_dev_path(pf_name, f"virtfn{vfid}/net")
     if os.path.isdir(vf_path):
         vf_nic = os.listdir(vf_path)
     else:
@@ -743,7 +700,7 @@ def generate_vpp_config(vpp_config_path, vpp_interfaces, vpp_bonds):
     :return: updated VPP config content.
     """
 
-    data = get_file_data(vpp_config_path)
+    data = common.get_file_data(vpp_config_path)
 
     # Add interface config to 'dpdk' section
     for vpp_interface in vpp_interfaces:
@@ -900,7 +857,7 @@ def update_vpp_mapping(vpp_interfaces, vpp_bonds):
         else:
             raise VppException('Bond %s not found in VPP.' % vpp_bond.name)
 
-    vpp_start_cli = get_file_data(_VPP_EXEC_FILE)
+    vpp_start_cli = common.get_file_data(_VPP_EXEC_FILE)
     for cli_line in cli_list:
         if not re.search(r'^\s*%s\s*$' % cli_line,
                          vpp_start_cli, re.MULTILINE):
